@@ -5,7 +5,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2024 Univention GmbH
+# Copyright 2013-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -81,8 +81,7 @@ class App:
         self.ucs_version = ucs_version
         self.meta_inf_dir = meta_inf_dir
         self.components_dir = components_dir
-        if server.endswith('/'):
-            server = server[:-1]
+        server = server.removesuffix('/')
         self.server = server
 
     def get_metainf_url(self):
