@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2015-2024 Univention GmbH
+# Copyright 2015-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -288,8 +288,7 @@ class App:
         self.container_id = self.ucr.get('appcenter/apps/%s/container' % self.app_name)
 
     def file(self, fname):
-        if fname.startswith('/'):
-            fname = fname[1:]
+        fname = fname.removeprefix('/')
         dirname = subprocess.check_output(['docker', 'inspect', '--format={{.GraphDriver.Data.MergedDir}}', self.container_id], text=True).strip()
         return os.path.join(dirname, fname)
 
