@@ -5,7 +5,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2024 Univention GmbH
+# Copyright 2013-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -96,7 +96,7 @@ class UMCSeleniumTest(ChecksAndWaits, Interactions):
         translator.set_language(self.language)
         logging.basicConfig(level=logging.INFO)
 
-    def __enter__(self) -> UMCSeleniumTest:  # FIXME Py3.9: Self
+    def __enter__(self) -> UMCSeleniumTest:  # FIXME: Py3.9: Self
         self.restart_umc()
         self._ucr.__enter__()
         if self.selenium_grid:
@@ -216,8 +216,7 @@ class UMCSeleniumTest(ChecksAndWaits, Interactions):
         if os.environ.get('JENKINS_WS'):
             logger.info('Browser Log URL: {}ws/test/selenium/selenium/{}'.format(os.environ['JENKINS_WS'], os.path.basename(filename)))
         with open(filename, 'w') as f:
-            for entry in self.driver.get_log('browser'):
-                f.write(f'{json.dumps(entry)}\n')
+            f.writelines(f'{json.dumps(entry)}\n' for entry in self.driver.get_log('browser'))
 
     def show_notifications(self, show_notifications: bool = True) -> None:
         if show_notifications:
@@ -246,7 +245,7 @@ class UMCSeleniumTest(ChecksAndWaits, Interactions):
         #     self.driver.add_cookie({'name': 'hideSummit%sDialog' % (year,), 'value': 'true'})
         #     self.driver.add_cookie({'name': 'hideSummit%sNotification' % (year,), 'value': 'true'})
         if not without_navigation:
-            self.driver.get(self.base_url + f'univention/login/?lang={language if language else self.language}')
+            self.driver.get(self.base_url + f'univention/login/?lang={language or self.language}')
 
         self.wait_until(
             expected_conditions.presence_of_element_located(
@@ -376,5 +375,5 @@ class UMCSeleniumTest(ChecksAndWaits, Interactions):
 
     # def select_table_item_by_name(self, itemname):
     #     elem = self.driver.find_element(By.XPATH, "//div[contains(text(), %s )]/parent::td" % json.dumps(itemname))
-    #     #TODO if not elem search itemname
+    #     # TODO: if not elem search itemname
     #     elem.click()
